@@ -135,6 +135,17 @@ class Dataset(BaseDataset):
             data:
             kind: @see DataKind
             transform:
+
+        usage for DataKind.MMAP_FILE
+
+        import os
+        import mmap
+
+        fp = open(filename, 'rb', os.O_RDONLY)
+        mm = mmap.mmap(fp.fileno(), 0, access=mmap.ACCESS_READ)
+        fp.close()
+
+        dataset = Dataset(mm, filename, kind=DataKind.MMAP_FILE)
         """
         self.kind = kind
         if kind not in self.data_kinds:
